@@ -7,9 +7,9 @@ import torch
 import matplotlib.pyplot as plt
 from IPython.display import display, clear_output
 from dl2050utils.ju import disablePrint, enablePrint, force_print
-from nn2.etc import *
-from nn2.cbs import Callback
-from nn2.metrics import *
+from dl2050nn.etc import *
+from dl2050nn.cbs import Callback
+from dl2050nn.metrics import *
 
 
 def key_metric(learner): return 4+len(learner.metrics)
